@@ -182,7 +182,9 @@ def transpile_token(
         elif "+" in parts:
             parts = parts + "* I"
 
-        return indent_str(f'stack.append(sympy.nsimplify("{parts}"))', indent)
+        return indent_str(
+            f'stack.append(sympy.nsimplify("{parts}", rational=True))', indent
+        )
     elif token.name == TokenType.GENERAL:
         return indent_str(elements.get(token.value, ("pass\n", -1))[0], indent)
     elif token.name == TokenType.COMPRESSED_NUMBER:
